@@ -30,10 +30,8 @@
 #include "bonobo-dock.h"
 #include "bonobo-dock-band.h"
 #include "bonobo-dock-item.h"
-#include <libgnome/gnome-macros.h>
 
-GNOME_CLASS_BOILERPLATE (BonoboDock, bonobo_dock,
-			 GtkContainer, GTK_TYPE_CONTAINER)
+G_DEFINE_TYPE (BonoboDock, bonobo_dock, GTK_TYPE_CONTAINER)
 
 #define noBONOBO_DOCK_DEBUG
 
@@ -192,7 +190,7 @@ bonobo_dock_class_init (BonoboDockClass *class)
 }
 
 static void
-bonobo_dock_instance_init (BonoboDock *dock)
+bonobo_dock_init (BonoboDock *dock)
 {
   GTK_WIDGET_SET_FLAGS (GTK_WIDGET (dock), GTK_NO_WINDOW);
 
@@ -484,7 +482,7 @@ bonobo_dock_map (GtkWidget *widget)
   g_return_if_fail (widget != NULL);
   g_return_if_fail (BONOBO_IS_DOCK(widget));
 
-  GNOME_CALL_PARENT (GTK_WIDGET_CLASS, map, (widget));
+  GTK_WIDGET_CLASS(bonobo_dock_parent_class)->map (widget);
 
   dock = BONOBO_DOCK (widget);
 
@@ -517,7 +515,7 @@ bonobo_dock_unmap (GtkWidget *widget)
 
   g_list_foreach (dock->floating_children, unmap_widget_foreach, NULL);
 
-  GNOME_CALL_PARENT (GTK_WIDGET_CLASS, unmap, (widget));
+  GTK_WIDGET_CLASS (bonobo_dock_parent_class)->unmap (widget);
 }
 
 
@@ -667,8 +665,8 @@ bonobo_dock_finalize (GObject *object)
   g_free (self->_priv);
   self->_priv = NULL;
 
-  if (G_OBJECT_CLASS (parent_class)->finalize)
-    (* G_OBJECT_CLASS (parent_class)->finalize) (object);
+  G_OBJECT_CLASS (bonobo_dock_parent_class)->finalize (object);
+
 }
 
 
